@@ -142,6 +142,35 @@ and its cdr element is used as height."
 		  image))
 	    image))))))
 
+(defun w3m-create-resized-image (url rate &optional referer size handler)
+  "Resize an cached image object.
+URL is the image file's url.
+RATE is resize percentage.
+If REFERER is non-nil, it is used as Referer: field.
+If SIZE is non-nil, its car element is used as width
+and its cdr element is used as height."
+  (if (not handler)
+      (w3m-process-with-wait-handler
+	(w3m-create-image url nil referer size handler))
+    (lexical-let ((url url)
+		  (rate rate)
+		  image)
+      (w3m-process-do-with-temp-buffer
+	  (type (progn
+		  (set-buffer-multibyte nil)
+		  (w3m-retrieve url 'raw nil nil referer handler)))
+	(when (w3m-image-type-available-p (setq type (w3m-image-type type)))
+	  (setq image (create-image (buffer-string) type t :ascent 'center))
+	  (progn
+	    (set-buffer-multibyte t)
+	    (w3m-process-do
+		(resized (w3m-resize-image-by-rate
+			  (plist-get (cdr image) :data)
+			  rate
+			  handler))
+	      (if resized (plist-put (cdr image) :data resized))
+	      image)))))))
+
 (defun w3m-insert-image (beg end image &rest args)
   "Display image on the current buffer.
 Buffer string between BEG and END are replaced with IMAGE."
@@ -378,6 +407,16 @@ If this variable is nil, never expired."
   :group 'w3m
   :type 'integer)
 
+(defcustom w3m-favicon-type 'xpm
+  "*Image type of display favicon."
+  :group 'w3m
+  :type (cons 'choice
+	      (mapcar (lambda (x)
+			`(const :tag ,(symbol-name x) ,x))
+		      (delq 'postscript
+			    (delq 'xbm
+				  (delq 'pbm (copy-sequence image-types)))))))
+
 (defvar w3m-favicon-cache-data nil
   "A list of favicon cache (internal variable).
 Each information is a list whose elements are:
@@ -401,7 +440,8 @@ Each information is a list whose elements are:
 	w3m-favicon-converted nil)
   (when (and w3m-use-favicon
 	     w3m-current-url
-	     (w3m-image-type-available-p 'xpm))
+	     (w3m-image-type-available-p 'xpm)
+	     (w3m-image-type-available-p w3m-favicon-type))
     (cond
      ((string-match "\\`about://\\([^/]+\\)/" url)
       (let ((icon (intern-soft (concat "w3m-about-" (match-string 1 url)
@@ -428,24 +468,25 @@ Each information is a list whose elements are:
       (or w3m-current-favicon-image
 	  w3m-favicon-converted
 	  (lexical-let ((height (number-to-string (frame-char-height)))
-			(buffer buffer)
-			handler)
-	    (setq w3m-favicon-converted t)
-	    (w3m-process-do
-		(xpm (w3m-imagick-start-convert-data
-		      handler
-		      (car w3m-current-favicon-data)
-		      (symbol-name (cdr w3m-current-favicon-data))
-		      "xpm" "-geometry" (or w3m-favicon-size
-					    (concat height "x" height))))
-	      (with-current-buffer buffer
-		(if xpm
-		    (setq w3m-current-favicon-image
-			  (create-image xpm
-					'xpm
-					t
-					:ascent 'center))
-		  (setq w3m-current-favicon-data nil)))))))))
+			(buffer buffer))
+	    (w3m-process-with-null-handler
+	      (setq w3m-favicon-converted t)
+	      (w3m-process-do
+		  (img (w3m-imagick-start-convert-data
+			handler
+			(car w3m-current-favicon-data)
+			(symbol-name (cdr w3m-current-favicon-data))
+			(symbol-name w3m-favicon-type)
+			"-geometry" (or w3m-favicon-size
+					(concat height "x" height))))
+		(with-current-buffer buffer
+		  (if img
+		      (setq w3m-current-favicon-image
+			    (create-image img
+					  w3m-favicon-type
+					  t
+					  :ascent 'center))
+		    (setq w3m-current-favicon-data nil))))))))))
 
 (defun w3m-retrieve-favicon (pair target &optional handler)
   (if (and (w3m-favicon-cache-p (car pair))
