@@ -152,6 +152,8 @@ cursor position and around there."
   (` (w3m-get-text-property-around 'w3m-href-anchor (, position))))
 (defmacro w3m-image (&optional position)
   (` (w3m-get-text-property-around 'w3m-image (, position))))
+(defmacro w3m-image-scale (&optional position)
+  (` (w3m-get-text-property-around 'w3m-image-scale (, position))))
 (defmacro w3m-submit (&optional position)
   (` (w3m-get-text-property-around 'w3m-submit (, position))))
 
@@ -269,12 +271,12 @@ An argument of nil means kill the current buffer."
 			   (buffer-name buffer)))
     (if (match-beginning 1)
 	(string-to-number (match-string 2 (buffer-name buffer)))
-      0)))
+      1))) ;; `1' should not be represented in the buffer name.
 
 (defsubst w3m-buffer-set-number (buffer number)
   (unless (eq (w3m-buffer-number buffer) number)
     (with-current-buffer buffer
-      (let ((newname (if (zerop number)
+      (let ((newname (if (= number 1)
 			 "*w3m*"
 		       (format "*w3m*<%d>" number))))
 	(unless (get-buffer newname)
@@ -290,12 +292,12 @@ An argument of nil means kill the current buffer."
 	   (setq x (cons x
 			 (if (match-beginning 1)
 			     (string-to-number (match-string 2 x))
-			   0))))
+			   1))))
       (if (string-match "\\`\\*w3m\\*\\(<\\([0-9]+\\)>\\)?\\'" y)
 	  (< (cdr x)
 	     (if (match-beginning 1)
 		 (string-to-number (match-string 2 y))
-	       0))
+	       1))
 	(string< (car x) y))
     (string< x y)))
 
@@ -469,6 +471,16 @@ variable `w3m-display-message-enable-logging'."
 				message-log-max)))
        (message ,string ,@args))))
 
+(defun w3m-display-progress-message (url)
+  "Show \"Reading URL...\" message in the middle of a buffer."
+  (insert (make-string (max 0 (/ (1- (window-height)) 2)) ?\n)
+	  "Reading " (w3m-url-strip-authinfo url) "...")
+  (beginning-of-line)
+  (let ((fill-column (window-width)))
+    (center-region (point) (point-max)))
+  (goto-char (point-min))
+  (sit-for 0))
+
 (if (featurep 'xemacs)
     (defalias 'w3m-function-max-args 'function-max-args)
   (eval-and-compile
